import {select, csv, scaleLinear, extent, scalePoint, 
        axisLeft, axisBottom, format} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = dd => {
  const xValue = d => d.acceleration;
  const xLabel = 'Acceleration';
  const yValue = d => d.horsepower;
  const yLabel = 'Horsepower';
  const circleRadius = 10;
  const margin = {top:50, right:50, bottom:100, left: 150};
  const innerwidth = width-margin.right-margin.left;
  const innerheight = height-margin.top-margin.bottom
  
  const xScale = scaleLinear()
  	.domain(extent(dd, xValue))
  	.range([0, innerwidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(dd, yValue))
  	.range([0, innerheight])
  	.nice();
  
  
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  
  const xTickFormat = number => 
  	format('.3s')(number)
  	.replace('G', 'B');
  
  const xAxis = axisBottom(xScale)
  	.tickFormat(xTickFormat)
  	.tickSize(-innerheight)
  	.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerwidth)
  	.tickPadding(5);
  
  const yAxisG = g.append('g').call(yAxis);
   
  yAxisG.selectAll('.domain')
  		.remove();
  
  
   yAxisG.append('text')
  	.attr('y',-50)
  	.attr('x', -innerheight/2)
  	.attr('fill', 'black')
  	.attr('transform', `rotate(-90)`)
  	.style('text-anchor', 'middle')
  	.text(yLabel);
  	 
  const xAxisG = g.append('g').call(xAxis)
 		.attr('transform', `translate(0, ${innerheight})`);
  
  
 xAxisG.selectAll('.domain').remove();
  
 xAxisG.append('text')
  	.attr('y',50)
  	.attr('x', innerwidth /2)
  	.attr('fill', 'black')
  	.text(xLabel);
  
  
	g.selectAll('circle').data(dd)
  	.enter().append('circle')
  		.attr('cx', pick => xScale(xValue(pick)))
  		.attr('cy', pick => yScale(yValue(pick)))
  		.attr('r', circleRadius)
  
  g.append('text')
  	.attr('y', -10)
		.text('Top 10 Population Country');
  
};

	

csv('https://vizhub.com/curran/datasets/auto-mpg.csv')
  .then(data => {
  data.forEach(d => {
    d.mpg = +d.mpg
    d.cylinders = +d.cylinders
    d.displacement = +d.displacement
    d.horsepower = +d.horsepower
    d.weight = +d.weight
    d.acceleration = +d.acceleration
    d.year = +d.year
  })
	render(data)
});



